BaseClass
=========

.. currentmodule:: hhpy.main

.. autoclass:: BaseClass
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~BaseClass.copy
      ~BaseClass.from_dict
      ~BaseClass.load
      ~BaseClass.read_pickle
      ~BaseClass.save
      ~BaseClass.to_dict
      ~BaseClass.to_pickle

   .. rubric:: Methods Documentation

   .. automethod:: copy
   .. automethod:: from_dict
   .. automethod:: load
   .. automethod:: read_pickle
   .. automethod:: save
   .. automethod:: to_dict
   .. automethod:: to_pickle
